summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/votrax.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/votrax.cpp')
-rw-r--r--src/devices/sound/votrax.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/devices/sound/votrax.cpp b/src/devices/sound/votrax.cpp
index 8b416da6188..2b1f91ced1d 100644
--- a/src/devices/sound/votrax.cpp
+++ b/src/devices/sound/votrax.cpp
@@ -127,11 +127,11 @@ void votrax_sc01_device::inflection_w(uint8_t data)
//-------------------------------------------------
// sound_stream_update - handle update requests
// for our sound stream
//-------------------------------------------------
-void votrax_sc01_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void votrax_sc01_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
for(int i=0; i<samples; i++) {
m_sample_count++;
@@ -168,7 +168,7 @@ void votrax_sc01_device::device_start()
m_mainclock = clock();
m_sclock = m_mainclock / 18.0;
m_cclock = m_mainclock / 36.0;
- m_stream = stream_alloc(0, 1, m_sclock);
+ m_stream = stream_alloc_legacy(0, 1, m_sclock);
m_timer = timer_alloc();
// reset outputs
@@ -127,11 +127,11 @@ void votrax_sc01_device::inflection_w(uint8_t data)
//-------------------------------------------------
-// sound_stream_update - handle update requests
+// sound_stream_update_legacy - handle update requests
// for our sound stream
//-------------------------------------------------